<%page args="workorder, optical_data" />

% if report.sale: ${ _("Sale") }: | ${ report.sale.identifier } % else: | ${ _("Work order") }: | ${ workorder.identifier} % endif
${ _("Date") }: | ${ format_date(workorder.open_date) } | ${ _("Deliver") }: | ${ format_date(workorder.estimated_finish) }
${ _("Desc") }: | ${ optical_data.patient }

Longe | Esf | Cil | Eixo | DNP | Alt | Prisma
OD: | ${ optical_data.re_distance_spherical } | ${ optical_data.re_distance_cylindrical } | ${ optical_data.re_distance_axis} | ${ optical_data.re_distance_pd } | ${ optical_data.re_distance_height } | ${ optical_data.re_distance_prism }
OE: | ${ optical_data.le_distance_spherical } | ${ optical_data.le_distance_cylindrical } | ${ optical_data.le_distance_axis } | ${ optical_data.le_distance_pd } | ${ optical_data.le_distance_height } | ${ optical_data.le_distance_prism }

Perto | Esf | Cil | Eixo | DNP | Adição
OD: | ${ optical_data.re_near_spherical } | ${ optical_data.re_near_cylindrical } | ${ optical_data.re_near_axis } | ${ optical_data.re_near_pd } | ${ optical_data.re_addition }
OE: | ${ optical_data.le_near_spherical } | ${ optical_data.le_near_cylindrical } | ${ optical_data.le_near_axis } | ${ optical_data.le_near_pd } | ${ optical_data.le_addition }

% if optical_data.frame_mva or optical_data.frame_mha or optical_data.frame_bridge or optical_data.frame_mda:

Armação | M.V.A. | M.H.A. | M.D.A. | Ponte
${ optical_data.frame_type_str } | ${ optical_data.frame_mva } | ${ optical_data.frame_mha } | ${ optical_data.frame_mda } | ${ optical_data.frame_bridge }
% endif